/**
 * @file
 * Some basic behaviors and utility functions for Paragraphs Role Visibility.
 */

(function ($, Drupal, once) {

  /**
   * Update 'Select all' checkbox based on child checkboxes statuses.
   * @param $selectAllCheckbox
   *  'Select all' checkbox.
   *  @param $checkboxes
   *   Child checkboxes.
   */
  var updateSelectAllCheckbox = function ($selectAllCheckbox, $checkboxes) {
    var $status = $checkboxes.not(':checked').length === 0;
    $selectAllCheckbox.prop('checked', $status);
  };

  /**
   * Add a select all checkbox, which checks each checkbox at once.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attaches select all functionality to the behavior form.
   */
  Drupal.behaviors.paragraphsRoleVisibilitySelectAll = {
    attach(context) {
      const selectAll = $(once(
        'paragraphsRoleVisibilitySelectAll',
        '[id^="paragraphs-role-visibility"] .js-form-item-options-value-all',
        context));

      if (selectAll.length) {
        selectAll.each(function (index, element) {
            const $selectAll = $(element);
            const $selectAllCheckbox = $selectAll.find('input[type=checkbox]');
            const $checkboxes = $selectAll
              .closest('.form-checkboxes')
              .find(
                '.js-form-type-checkbox:not(.js-form-item-options-value-all) input[type="checkbox"]',
              );

            //Set default 'Select all' checkbox status.
            updateSelectAllCheckbox($selectAllCheckbox, $checkboxes);

            // Show the select all checkbox.
            $selectAll.show();
            $selectAllCheckbox.on('click', function () {
              // Update all checkbox beside the select all checkbox.
              $checkboxes.prop('checked', $(this).is(':checked'));
            });

            $checkboxes.on('click', function () {
              //Update 'Select all' checkbox status after click on any of child checkboxes.
              updateSelectAllCheckbox($selectAllCheckbox, $checkboxes);
            });
          },
        );
      }
    },
  };

})(jQuery, Drupal, once);
